@@ -38,6 +38,7 @@
 
 EtmV4ITrcPacket::EtmV4ITrcPacket()
 {
+    protocol_version = 0x42;    // min protocol version.
 }
 
 EtmV4ITrcPacket::~EtmV4ITrcPacket()
@@ -101,6 +102,8 @@ void EtmV4ITrcPacket::toString(std::string &str) const
         contextStr(ctxtStr);
     case ETM4_PKT_I_ADDR_L_32IS0:
     case ETM4_PKT_I_ADDR_L_32IS1:
+    case ETE_PKT_I_SRC_ADDR_L_32IS0:
+    case ETE_PKT_I_SRC_ADDR_L_32IS1:
         trcPrintableElem::getValStr(valStr, (v_addr.size == VA_64BIT) ? 64 : 32, v_addr.valid_bits, v_addr.val, true, (v_addr.pkt_bits < 32) ? v_addr.pkt_bits : 0);
         str += "; Addr=" + valStr + "; " + ctxtStr;
         break;
@@ -110,6 +113,8 @@ void EtmV4ITrcPacket::toString(std::string &str) const
         contextStr(ctxtStr);
     case ETM4_PKT_I_ADDR_L_64IS0:
     case ETM4_PKT_I_ADDR_L_64IS1:
+    case ETE_PKT_I_SRC_ADDR_L_64IS0:
+    case ETE_PKT_I_SRC_ADDR_L_64IS1:
         trcPrintableElem::getValStr(valStr, (v_addr.size == VA_64BIT) ? 64 : 32, v_addr.valid_bits, v_addr.val, true, (v_addr.pkt_bits < 64) ? v_addr.pkt_bits : 0);
         str += "; Addr=" + valStr + "; " + ctxtStr;
         break;
@@ -121,11 +126,14 @@ void EtmV4ITrcPacket::toString(std::string &str) const
 
     case ETM4_PKT_I_ADDR_S_IS0:
     case ETM4_PKT_I_ADDR_S_IS1:
+    case ETE_PKT_I_SRC_ADDR_S_IS0:
+    case ETE_PKT_I_SRC_ADDR_S_IS1:
         trcPrintableElem::getValStr(valStr, (v_addr.size == VA_64BIT) ? 64 : 32, v_addr.valid_bits, v_addr.val, true, v_addr.pkt_bits);
         str += "; Addr=" + valStr;
         break;
 
     case ETM4_PKT_I_ADDR_MATCH:
+    case ETE_PKT_I_SRC_ADDR_MATCH:
         addrMatchIdx(valStr);
         str += ", " + valStr;
         trcPrintableElem::getValStr(valStr, (v_addr.size == VA_64BIT) ? 64 : 32, v_addr.valid_bits, v_addr.val, true);
@@ -161,7 +169,10 @@ void EtmV4ITrcPacket::toString(std::string &str) const
         {
             std::ostringstream oss;
             oss << "; INFO=" << std::hex << "0x" << trace_info.val;
-            oss << " { CC." << std::dec << trace_info.bits.cc_enabled << " }";
+            oss << " { CC." << std::dec << trace_info.bits.cc_enabled;
+            if (isETE())
+                oss << ", TSTATE." << std::dec << trace_info.bits.in_trans_state;
+            oss << " }";
             if (trace_info.bits.cc_enabled)
                 oss << "; CC_THRESHOLD=" << std::hex << "0x" << cc_threshold;
             str += oss.str();
@@ -177,8 +188,96 @@ void EtmV4ITrcPacket::toString(std::string &str) const
             str += oss.str();
         }
         break;
+
+    case ETM4_PKT_I_CANCEL_F1:
+        {
+            std::ostringstream oss;
+            oss << "; Cancel(" << std::dec << cancel_elements << ")";
+            str += oss.str();
+        }
+        break;
+
+    case ETM4_PKT_I_CANCEL_F1_MISPRED:
+        {
+            std::ostringstream oss;
+            oss << "; Cancel(" << std::dec << cancel_elements << "), Mispredict";
+            str += oss.str();
+        }
+        break;
+
+    case ETM4_PKT_I_MISPREDICT:
+        {
+            std::ostringstream oss;
+            oss << "; ";
+            if (atom.num) {
+                atomSeq(valStr);
+                oss << "Atom: " << valStr << ", ";
+            }
+            oss << "Mispredict";
+            str += oss.str();
+        }
+        break;
+
+    case ETM4_PKT_I_CANCEL_F2:
+        {
+            std::ostringstream oss;
+            oss << "; ";
+            if (atom.num) {
+                atomSeq(valStr);
+                oss << "Atom: " << valStr << ", ";
+            }
+            oss << "Cancel(1), Mispredict";
+            str += oss.str();
+        }
+        break;
+
+    case ETM4_PKT_I_CANCEL_F3:
+        {
+            std::ostringstream oss;
+            oss << "; ";
+            if (atom.num) {
+                oss << "Atom: E, ";
+            }
+            oss << "Cancel(" << std::dec << cancel_elements << "), Mispredict";
+            str += oss.str();
+        }
+        break;
+
+    case ETM4_PKT_I_COMMIT:
+        {
+            std::ostringstream oss;
+            oss << "; Commit(" << std::dec << commit_elements << ")";
+            str += oss.str();
+        }
+        break;
+
+    case ETM4_PKT_I_Q:
+        {
+            std::ostringstream oss;
+            if (Q_pkt.count_present)
+            {
+                oss << "; Count(" << std::dec << Q_pkt.q_count << ")";
+                str += oss.str();
+            }
+            else
+                str += "; Count(Unknown)";
+
+            if (Q_pkt.addr_match) 
+            {
+                addrMatchIdx(valStr);
+                str += "; " + valStr;
+            }
+
+            if (Q_pkt.addr_present || Q_pkt.addr_match)
+            {
+                trcPrintableElem::getValStr(valStr, (v_addr.size == VA_64BIT) ? 64 : 32, v_addr.valid_bits, v_addr.val, true, (v_addr.pkt_bits < 64) ? v_addr.pkt_bits : 0);
+                str += "; Addr=" + valStr;
+            }
+        }
+        break;
     }
-}
+
+}   
 
 void EtmV4ITrcPacket::toStringFmt(const uint32_t fmtFlags, std::string &str) const
 {
@@ -262,6 +361,21 @@ const char *EtmV4ITrcPacket::packetTypeName(const ocsd_etmv4_i_pkt_type type, co
         pDesc = "Exception Return.";
         break;
 
+    case ETE_PKT_I_COMMIT_WIN_MV:
+        pName = "I_COMMIT_WIN_MV";
+        pDesc = "Commit window move.";
+        break;
+
+    case ETE_PKT_I_TRANS_ST:
+        pName = "I_TRANS_ST";
+        pDesc = "Transaction Start.";
+        break;
+
+    case ETE_PKT_I_TRANS_COMMIT:
+        pName = "I_TRANS_COMMIT";
+        pDesc = "Transaction Commit.";
+        break;
+
     case ETM4_PKT_I_CCNT_F1:
         pName = "I_CCNT_F1";
         pDesc = "Cycle Count format 1.";
@@ -297,6 +411,12 @@ const char *EtmV4ITrcPacket::packetTypeName(const ocsd_etmv4_i_pkt_type type, co
         pDesc = "Cancel Format 1.";
         break;
 
+    case ETM4_PKT_I_CANCEL_F1_MISPRED:
+        pName = "I_CANCEL_F1_MISPRED";
+        pDesc = "Cancel Format 1 + Mispredict.";
+        break;
+
+
     case ETM4_PKT_I_MISPREDICT:
         pName = "I_MISPREDICT";
         pDesc = "Mispredict.";
@@ -387,6 +507,11 @@ const char *EtmV4ITrcPacket::packetTypeName(const ocsd_etmv4_i_pkt_type type, co
         pDesc = "Address & Context, Long, 64 bit, IS1.";
         break;
 
+    case ETE_PKT_I_TS_MARKER:
+        pName = "I_TS_MARKER";
+        pDesc = "Timestamp Marker";
+        break;
+
     case ETM4_PKT_I_ADDR_MATCH:
         pName = "I_ADDR_MATCH";
         pDesc = "Exact Address Match.";
@@ -427,6 +552,41 @@ const char *EtmV4ITrcPacket::packetTypeName(const ocsd_etmv4_i_pkt_type type, co
         pDesc = "Q Packet.";
         break;
 
+    case ETE_PKT_I_SRC_ADDR_MATCH:
+        pName = "I_SRC_ADDR_MATCH";
+        pDesc = "Exact Source Address Match.";
+        break;
+
+    case ETE_PKT_I_SRC_ADDR_S_IS0:
+        pName = "I_SRC_ADDR_S_IS0";
+        pDesc = "Source Address, Short, IS0.";
+        break;
+
+    case ETE_PKT_I_SRC_ADDR_S_IS1:
+        pName = "I_SRC_ADDR_S_IS1";
+        pDesc = "Source Address, Short, IS1.";
+        break;
+
+    case ETE_PKT_I_SRC_ADDR_L_32IS0:
+        pName = "I_SCR_ADDR_L_32IS0";
+        pDesc = "Source Address, Long, 32 bit, IS0.";
+        break;
+
+    case ETE_PKT_I_SRC_ADDR_L_32IS1:
+        pName = "I_SRC_ADDR_L_32IS1";
+        pDesc = "Source Address, Long, 32 bit, IS1.";
+        break;
+
+    case ETE_PKT_I_SRC_ADDR_L_64IS0:
+        pName = "I_SRC_ADDR_L_64IS0";
+        pDesc = "Source Address, Long, 64 bit, IS0.";
+        break;
+
+    case ETE_PKT_I_SRC_ADDR_L_64IS1:
+        pName = "I_SRC_ADDR_L_64IS1";
+        pDesc = "Source Address, Long, 64 bit, IS1.";
+        break;
+
     case ETM4_PKT_I_ATOM_F6:
         pName = "I_ATOM_F6";
         pDesc = "Atom format 6.";
@@ -472,6 +632,16 @@ const char *EtmV4ITrcPacket::packetTypeName(const ocsd_etmv4_i_pkt_type type, co
         pDesc = "Overflow.";
         break;
 
+    case ETE_PKT_I_PE_RESET:
+        pName = "I_PE_RESET";
+        pDesc = "PE Reset.";
+        break;
+
+    case ETE_PKT_I_TRANS_FAIL:
+        pName = "I_TRANS_FAIL";
+        pDesc = "Transaction Fail.";
+        break;
+
     default:
         break;
     }
